==> e16-0.16.8.6.tar.gz: e16-0.16.8.6/src/eimage.h <==
/*
 * Copyright (C) 2004-2007 Kim Woelders
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _EIMAGE_H_
#define _EIMAGE_H_

#include <X11/Xlib.h>
#include "xwin.h"

typedef void        EImage;
typedef void        EImageColorModifier;

typedef struct
{
   int                 left, right, top, bottom;
} EImageBorder;

void                EImageInit(Display * dpy);

EImage             *EImageCreate(int w, int h);
EImage             *EImageCreateFromData(int w, int h, unsigned int *data);
EImage             *EImageCreateScaled(EImage * im, int sx, int sy,
				       int sw, int sh, int dw, int dh);

void                EImageFree(EImage * im);
void                EImageDecache(EImage * im);

void                EImageSave(EImage * im, const char *file);
EImage             *EImageLoad(const char *file);

void                EImageCheckAlpha(EImage * im);

void                EImageSetHasAlpha(EImage * im, int has_alpha);
void                EImageSetBorder(EImage * im, EImageBorder * border);

int                 EImageHasAlpha(EImage * im);
void                EImageGetSize(EImage * im, int *pw, int *ph);
void               *EImageGetData(EImage * im);

void                EImageFill(EImage * im, int x, int y, int w, int h, int r,
			       int g, int b, int a);
void                EImageOrientate(EImage * im, int orientation);

void                EImageBlend(EImage * im, EImage * src, int blend,
				int sx, int sy, int sw, int sh,
				int dx, int dy, int dw, int dh,
				int merge_alpha, int anti_alias);
void                EImageBlendCM(EImage * im, EImage * src,
				  EImageColorModifier * icm);
void                EImageTile(EImage * im, EImage * tile, int blend, int tw,
			       int th, int dx, int dy, int dw, int dh, int ox,
			       int oy);

EImage             *EImageGrabDrawable(Drawable draw, Pixmap mask,
				       int x, int y, int w, int h, int grab);
EImage             *EImageGrabDrawableScaled(Win win,
					     Drawable draw, Pixmap mask,
					     int x, int y, int w, int h,
					     int iw, int ih, int grab,
					     int get_mask_from_shape);

void                EImageRenderOnDrawable(EImage * im, Win win, Drawable draw,
					   int x, int y, int w, int h,
					   int blend);

void                EImageRenderPixmaps(EImage * im, Win win,
					Pixmap * pmap, Pixmap * mask,
					int w, int h);
void                EImagePixmapFree(Pixmap pmap);

EImageColorModifier *EImageColorModifierCreate(void);
void                EImageColorModifierSetTables(EImageColorModifier * icm,
						 unsigned char *r,
						 unsigned char *g,
						 unsigned char *b,
						 unsigned char *a);

void                ScaleRect(Win wsrc, Drawable src,
			      Win wdst, Pixmap dst, Pixmap * pdst,
			      int sx, int sy, int sw, int sh,
			      int dx, int dy, int dw, int dh, int scale);

void                EDrawableDumpImage(Drawable draw, const char *txt);

EImage             *ThemeImageLoad(const char *file);

#endif /* _EIMAGE_H_ */

==> e16_0.16.8.10.dfsg.1.orig.tar.gz: e16-0.16.8.10.dfsg.1/src/eimage.h <==
/*
 * Copyright (C) 2004-2007 Kim Woelders
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies of the Software, its documentation and marketing & publicity
 * materials, and acknowledgment shall be given in the documentation, materials
 * and software packages that this Software was used.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 * IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#ifndef _EIMAGE_H_
#define _EIMAGE_H_

#include <X11/Xlib.h>
#include "xwin.h"

typedef void        EImage;
typedef void        EImageColorModifier;

typedef struct
{
   int                 left, right, top, bottom;
} EImageBorder;

#define EIMAGE_BLEND            0x01
#define EIMAGE_ANTI_ALIAS       0x02
#define EIMAGE_HIGH_MASK_THR    0x04

void                EImageInit(Display * dpy);
int                 EImageSetCacheSize(int size);

EImage             *EImageCreate(int w, int h);
EImage             *EImageCreateFromData(int w, int h, unsigned int *data);
EImage             *EImageCreateScaled(EImage * im, int sx, int sy,
				       int sw, int sh, int dw, int dh);

void                EImageFree(EImage * im);
void                EImageDecache(EImage * im);

void                EImageSave(EImage * im, const char *file);
EImage             *EImageLoad(const char *file);

void                EImageCheckAlpha(EImage * im);

void                EImageSetHasAlpha(EImage * im, int has_alpha);
void                EImageSetBorder(EImage * im, EImageBorder * border);

int                 EImageHasAlpha(EImage * im);
void                EImageGetSize(EImage * im, int *pw, int *ph);
void               *EImageGetData(EImage * im);

void                EImageFill(EImage * im, int x, int y, int w, int h, int r,
			       int g, int b, int a);
void                EImageOrientate(EImage * im, int orientation);

void                EImageBlend(EImage * im, EImage * src, int flags,
				int sx, int sy, int sw, int sh,
				int dx, int dy, int dw, int dh,
				int merge_alpha);
void                EImageBlendCM(EImage * im, EImage * src,
				  EImageColorModifier * icm);
void                EImageTile(EImage * im, EImage * tile, int flags, int tw,
			       int th, int dx, int dy, int dw, int dh, int ox,
			       int oy);

EImage             *EImageGrabDrawable(Drawable draw, Pixmap mask,
				       int x, int y, int w, int h, int grab);
EImage             *EImageGrabDrawableScaled(Win win,
					     Drawable draw, Pixmap mask,
					     int x, int y, int w, int h,
					     int iw, int ih, int grab,
					     int get_mask_from_shape);

void                EImageRenderOnDrawable(EImage * im, Win win, Drawable draw,
					   int flags,
					   int x, int y, int w, int h);

void                EImageRenderPixmaps(EImage * im, Win win, int flags,
					Pixmap * pmap, Pixmap * mask,
					int w, int h);
void                EImagePixmapFree(Pixmap pmap);

EImageColorModifier *EImageColorModifierCreate(void);
void                EImageColorModifierSetTables(EImageColorModifier * icm,
						 unsigned char *r,
						 unsigned char *g,
						 unsigned char *b,
						 unsigned char *a);

void                ScaleRect(Win wsrc, Drawable src,
			      Win wdst, Pixmap dst, Pixmap * pdst,
			      int sx, int sy, int sw, int sh,
			      int dx, int dy, int dw, int dh, int scale);

void                EDrawableDumpImage(Drawable draw, const char *txt);

EImage             *ThemeImageLoad(const char *file);

#endif /* _EIMAGE_H_ */
